@@ -12,14 +12,19 @@
 #ifndef BLOWFISH_H
 #define BLOWFISH_H
 
+
 class Server;
 
+class QString;
+class QCString;
+
+
 namespace Konversation
 {
 
     int findOccurrence(const QCString& input, const QCString& separator, int nth);
     void decrypt(const QString& recipient, QCString& cipher, Server* server);
     void decryptTopic(const QString& recipient, QCString& cipher, Server* server);
-    void encrypt(const QString& recipient, QString& cipher, Server* server);
+    bool encrypt(const QString& key, QCString& cipher);
 }
 #endif
