@@ -14,6 +14,7 @@
 
 #include <kdialogbase.h>
 
+
 class QLineEdit;
 
 namespace Konversation
@@ -26,7 +27,7 @@ namespace Konversation
         Q_OBJECT
 
         public:
-            ChannelDialog(const QString& title, QWidget *parent = 0, const char *name = 0);
+            explicit ChannelDialog(const QString& title, QWidget *parent = 0, const char *name = 0);
             ~ChannelDialog();
 
             void setChannelSettings(const ChannelSettings& channel);
