@@ -6,10 +6,14 @@
 */
 
 /*
-  copyright: (C) 2004 by Peter Simonsson
-  email:     psn@linux.se
+  Copyright (C) 2004 Peter Simonsson <psn@linux.se>
+  Copyright (C) 2006-2008 Eike Hein <hein@kde.org>
 */
 
+#include "common.h"
+#include "konversationapplication.h"
+#include "config/preferences.h"
+
 #include <qcstring.h>
 #include <qstring.h>
 #include <qregexp.h>
@@ -18,9 +22,6 @@
 #include <qpainter.h>
 #include <klocale.h>
 
-#include "common.h"
-#include "konversationapplication.h"
-#include "config/preferences.h"
 
 namespace Konversation
 {
@@ -29,7 +30,7 @@ namespace Konversation
     #include "unicode.cpp"
 
     static QRegExp colorRegExp("((\003([0-9]|0[0-9]|1[0-5])(,([0-9]|0[0-9]|1[0-5])|)|\017)|\x02|\x09|\x13|\x16|\x1f)");
-    static QRegExp urlPattern("((www\\.(?!\\.)|(fish|(f|ht)tp(|s))://)(\\.?[\\d\\w/,\\':~\\?=;#@\\-\\+\\%\\*\\{\\}\\!\\(\\)]|&)+)|"
+    static QRegExp urlPattern("((www\\.(?!\\.)|(fish|irc|(f|sf|ht)tp(|s))://)(\\.?[\\d\\w/,\\':~\\?=;#@\\-\\+\\%\\*\\{\\}\\!\\(\\)]|&)+)|"
         "([-.\\d\\w]+@[-.\\d\\w]{2,}\\.[\\w]{2,})");
     static QRegExp tdlPattern("(.*)\\.(\\w+),$");
 
@@ -53,27 +54,38 @@ namespace Konversation
         QString filteredLine = text;
         QString linkColor = Preferences::color(Preferences::Hyperlink).name();
         QString link;
+        QString insertText;
+        int pos = 0;
+        int urlLen = 0;
+        QString href;
 
         if(useCustomColor)
         {
-            link = "\\1<font color=\""+linkColor+"\"><a href=\"#\\2\">\\2</a></font>";
+            link = "<font color=\""+linkColor+"\"><a href=\"#%1\">%2</a></font>";
         }
         else
         {
-            link = "\\1<a href=\"#\\2\">\\2</a>";
+            link = "<a href=\"#%1\">%2</a>";
         }
 
         if(filteredLine.contains("#"))
         {
-          QRegExp chanExp("(^|\\s|^\"|\\s\"|,|'|\\(|\\:|!|@|%|\\+)(#[^,\\s;\\)\\:\\/\\(\\<\\>]*[^.,\\s;\\)\\:\\/\\(\"\''\\<\\>])");
-            filteredLine.replace(chanExp, link);
+            QRegExp chanExp("(^|\\s|^\"|\\s\"|,|'|\\(|\\:|!|@|%|\\+)(#[^,\\s;\\)\\:\\/\\(\\<\\>]*[^.,\\s;\\)\\:\\/\\(\"\''\\<\\>])");
+            while((pos = chanExp.search(filteredLine, pos)) >= 0)
+            {
+                href = chanExp.cap(2);
+                urlLen = href.length();
+                pos += chanExp.cap(1).length();
+
+                // HACK:Use space as a placeholder for \ as Qt tries to be clever and does a replace to / in urls in QTextEdit
+                insertText = link.arg(QString(href).replace('\\', " "), href);
+                filteredLine.replace(pos, urlLen, insertText);
+                pos += insertText.length();
+            }
         }
 
-        int pos = 0;
-        int urlLen = 0;
-        QString append;
-        QString href;
-        QString insertText;
+        pos = 0;
+        urlLen = 0;
 
         urlPattern.setCaseSensitive(false);
         QString protocol;
@@ -89,6 +101,8 @@ namespace Konversation
 
         while((pos = urlPattern.search(filteredLine, pos)) >= 0)
         {
+            QString append;
+
             // check if the matched text is already replaced as a channel
             if ( filteredLine.findRev( "<a", pos ) > filteredLine.findRev( "</a>", pos ) )
             {
@@ -107,6 +121,13 @@ namespace Konversation
                 append = ',';
             }
 
+            // Don't consider trailing semicolon part of link.
+            if (href.right(1) == ";")
+            {
+                href.truncate(href.length()-1);
+                append = ';';
+            }
+
             // Don't consider trailing closing parenthesis part of link when
             // there's an opening parenthesis preceding the beginning of the
             // URL or there is no opening parenthesis in the URL at all.
@@ -128,8 +149,9 @@ namespace Konversation
             else if (urlPattern.cap(1).isEmpty())
                 protocol = "mailto:";
 
-            // Use \003 as a placeholder for & so we can readd them after changing all & in the normal text to &amp;
-            insertText = link.arg(protocol, QString(href).replace('&', "\x0b"), href) + append;
+            // Use \x0b as a placeholder for & so we can readd them after changing all & in the normal text to &amp;
+            // HACK Replace % with \x03 in the url to keep Qt from doing stupid things
+            insertText = link.arg(protocol, QString(href).replace('&', "\x0b").replace('%', "\x03"), href) + append;
             filteredLine.replace(pos, urlLen, insertText);
             pos += insertText.length();
             KonversationApplication::instance()->storeUrl(fromNick, href);
