@@ -10,9 +10,16 @@
   Copyright (C) 2005 Ismail Donmez <ismail@kde.org>
   Copyright (C) 2005 Peter Simonsson <psn@linux.se>
   Copyright (C) 2005 John Tapsell <johnflux@gmail.com>
-  Copyright (C) 2005 Eike Hein <sho@eikehein.com>
+  Copyright (C) 2005-2008 Eike Hein <hein@kde.org>
 */
 
+#include "config/preferences.h"
+#include "identity.h"
+#include "ignore.h"
+#include "highlight.h"
+#include "commit.h"
+#include "version.h"
+
 #include <ktoolbar.h>
 #include <kstandarddirs.h>
 #include <kstaticdeleter.h>
@@ -27,12 +34,6 @@
 #include <qregexp.h>
 #include <qfileinfo.h>
 
-#include "config/preferences.h"
-#include "identity.h"
-#include "ignore.h"
-#include "highlight.h"
-#include "commit.h"
-#include "version.h"
 
 Preferences *Preferences::mSelf = 0;
 static KStaticDeleter<Preferences> staticPreferencesDeleter;
@@ -55,10 +56,11 @@ Preferences::Preferences()
     mIdentity=new Identity();
     mIdentity->setName(i18n("Default Identity"));
     addIdentity(mIdentity);
+    mIgnoreList.setAutoDelete(true);
 
     KUser user(KUser::UseRealUserID);
-    setIdent(user.loginName());
-    setRealName(user.fullName());
+    mIdentity->setIdent(user.loginName());
+    mIdentity->setRealName(user.fullName());
 
     QStringList nickList;
     nickList.append(user.loginName());
@@ -66,30 +68,25 @@ Preferences::Preferences()
     nickList.append(user.loginName() + "__");
     mIdentity->setNicknameList(nickList);
 
-    setPartReason("Konversation terminated!");
-    setKickReason("User terminated!");
-
-    setShowAwayMessage(false);
-    setAwayMessage("/me is away: %s");
-    setUnAwayMessage("/me is back.");
     Konversation::ServerGroupSettingsPtr serverGroup = new Konversation::ServerGroupSettings;
     serverGroup->setName("Freenode");
     Konversation::ServerSettings server;
-    server.setServer("irc.freenode.org");
+    server.setHost("irc.freenode.org");
+    server.setPort(8001);
     serverGroup->addServer(server);
     serverGroup->setIdentityId(mIdentity->id());
     Konversation::ChannelSettings channel;
     channel.setName("#kde");
     serverGroup->addChannel(channel);
     serverGroup->setExpanded(false);
-    mServerGroupList.append(serverGroup);
+    addServerGroup(serverGroup);
     setQuickButtonList(defaultQuickButtonList());
     setAutoreplaceList(defaultAutoreplaceList());
 }
 
 Preferences::~Preferences()
 {
-    clearIdentityList();
+    mIdentityList.clear();
 
     if ( mSelf == this )
         staticPreferencesDeleter.setObject( mSelf, 0, false );
@@ -155,6 +152,8 @@ void Preferences::setServerGroupList(const Konversation::ServerGroupList& list)
 {
     self()->mServerGroupList.clear();
     self()->mServerGroupList = list;
+
+    Konversation::ServerGroupList::iterator it;
 }
 
 void Preferences::addServerGroup(Konversation::ServerGroupSettingsPtr serverGroup)
@@ -164,16 +163,16 @@ void Preferences::addServerGroup(Konversation::ServerGroupSettingsPtr serverGrou
 
 const Konversation::ServerGroupSettingsPtr Preferences::serverGroupById(int id)
 {
-    if(!self()->mServerGroupList.count())
+    if (!self()->mServerGroupList.count())
     {
         return 0;
     }
 
     Konversation::ServerGroupList::iterator it;
 
-    for(it = self()->mServerGroupList.begin(); it != self()->mServerGroupList.end(); ++it)
+    for (it = self()->mServerGroupList.begin(); it != self()->mServerGroupList.end(); ++it)
     {
-        if((*it)->id() == id)
+        if ((*it)->id() == id)
         {
             return (*it);
         }
@@ -184,18 +183,18 @@ const Konversation::ServerGroupSettingsPtr Preferences::serverGroupById(int id)
 
 const Konversation::ServerGroupSettingsPtr Preferences::serverGroupByServer(const QString& server)
 {
-    if(!self()->mServerGroupList.count())
+    if (!self()->mServerGroupList.count())
     {
         return 0;
     }
 
     Konversation::ServerGroupList::iterator it;
 
-    for(it = self()->mServerGroupList.begin(); it != self()->mServerGroupList.end(); ++it)
+    for (it = self()->mServerGroupList.begin(); it != self()->mServerGroupList.end(); ++it)
     {
         for (uint i = 0; i != (*it)->serverList().count(); i++)
         {
-            if ((*it)->serverByIndex(i).server().lower() == server)
+            if ((*it)->serverByIndex(i).host().lower() == server)
             {
                 return (*it);
             }
@@ -209,7 +208,7 @@ int Preferences::serverGroupIdByName(const QString& serverGroup)
 {
     Konversation::ServerGroupList::iterator it;
 
-    for(it = self()->mServerGroupList.begin(); it != self()->mServerGroupList.end(); ++it)
+    for (it = self()->mServerGroupList.begin(); it != self()->mServerGroupList.end(); ++it)
     {
         if((*it)->name().lower() == serverGroup.lower())
         {
@@ -217,7 +216,7 @@ int Preferences::serverGroupIdByName(const QString& serverGroup)
         }
     }
 
-    return 0;
+    return -1;
 }
 
 bool Preferences::isServerGroup(const QString& server)
@@ -237,18 +236,19 @@ bool Preferences::isServerGroup(const QString& server)
 
 void Preferences::removeServerGroup(int id)
 {
-    if(!self()->mServerGroupList.count())
+    if (!self()->mServerGroupList.count())
     {
         return;
     }
 
     Konversation::ServerGroupList::iterator it;
 
-    for(it = self()->mServerGroupList.begin(); it != self()->mServerGroupList.end(); ++it)
+    for (it = self()->mServerGroupList.begin(); it != self()->mServerGroupList.end(); ++it)
     {
-        if((*it)->id() == id)
+        if ((*it)->id() == id)
         {
             self()->mServerGroupList.remove(it);
+
             return;
         }
     }
@@ -340,7 +340,7 @@ const QString Preferences::notifyStringByGroupName(const QString& groupName)
     return notifyListByGroupName(groupName).join(" ");
 }
 
-const bool Preferences::addNotify(int serverGroupId, const QString& newPattern)
+bool Preferences::addNotify(int serverGroupId, const QString& newPattern)
 {
     if (!self()->mNotifyList[serverGroupId].contains(newPattern))
     {
@@ -352,7 +352,7 @@ const bool Preferences::addNotify(int serverGroupId, const QString& newPattern)
     return false;
 }
 
-const bool Preferences::removeNotify(const QString& groupName, const QString& pattern)
+bool Preferences::removeNotify(const QString& groupName, const QString& pattern)
 {
   int id=serverGroupIdByName(groupName);
   if(!id) return false;
@@ -370,7 +370,7 @@ const bool Preferences::removeNotify(const QString& groupName, const QString& pa
     return false;
 }
 
-const bool Preferences::isNotify(int serverGroupId, const QString& pattern)
+bool Preferences::isNotify(int serverGroupId, const QString& pattern)
 {
     if (self()->mNotifyList.find(serverGroupId) != self()->mNotifyList.end())
     {
@@ -381,7 +381,7 @@ const bool Preferences::isNotify(int serverGroupId, const QString& pattern)
     return false;
 }
 
-const bool Preferences::hasNotifyList(int serverGroupId)
+bool Preferences::hasNotifyList(int serverGroupId)
 {
     if (self()->mNotifyList.find(serverGroupId) != self()->mNotifyList.end())
         return true;
@@ -398,9 +398,9 @@ void Preferences::clearIdentityList()
     self()->mIdentityList.clear();
 }
 
-const QValueList<IdentityPtr> Preferences::identityList() { return self()->mIdentityList; }
+const IdentityList Preferences::identityList() { return self()->mIdentityList; }
 
-void Preferences::setIdentityList(const QValueList<IdentityPtr>& list)
+void Preferences::setIdentityList(const IdentityList& list)
 {
     self()->mIdentityList.clear();
     self()->mIdentityList = list;
@@ -471,6 +471,8 @@ QStringList Preferences::defaultAliasList()
         }
     }
 
+    delete fileInfo;
+
     return aliasList;
 }
 
@@ -487,7 +489,7 @@ void Preferences::setPartReason(const QString &newReason) { self()->mIdentityLis
 const QString Preferences::kickReason() { return self()->mIdentityList[0]->getKickReason(); }
 void Preferences::setKickReason(const QString &newReason) { self()->mIdentityList[0]->setKickReason(newReason); }
 
-const bool Preferences::showAwayMessage() { return self()->mIdentityList[0]->getShowAwayMessage(); }
+bool Preferences::showAwayMessage() { return self()->mIdentityList[0]->getShowAwayMessage(); }
 void Preferences::setShowAwayMessage(bool state) { self()->mIdentityList[0]->setShowAwayMessage(state); }
 
 const QString Preferences::awayMessage() { return self()->mIdentityList[0]->getAwayMessage(); }
@@ -521,7 +523,7 @@ void Preferences::setAutoUserhost(bool state)
     PreferencesBase::setAutoUserhost(state);
 }
 
-const bool Preferences::dialogFlag(const QString& flagName)
+bool Preferences::dialogFlag(const QString& flagName)
 {
     KConfig* config=KApplication::kApplication()->config();
 
@@ -554,32 +556,35 @@ void Preferences::setDialogFlag(const QString& flagName,bool state)
 // Channel Encodings
 const QString Preferences::channelEncoding(const QString& server,const QString& channel)
 {
-    if(self()->mChannelEncodingsMap.contains(server))
-        if(self()->mChannelEncodingsMap[server].contains(channel.lower()))
-            return self()->mChannelEncodingsMap[server][channel.lower()];
+    return channelEncoding(serverGroupIdByName(server),channel);
+}
+
+const QString Preferences::channelEncoding(int serverGroupId,const QString& channel)
+{
+    if(self()->mChannelEncodingsMap.contains(serverGroupId))
+        if(self()->mChannelEncodingsMap[serverGroupId].contains(channel.lower()))
+            return self()->mChannelEncodingsMap[serverGroupId][channel.lower()];
     return QString();
 }
 
 void Preferences::setChannelEncoding(const QString& server,const QString& channel,const QString& encoding)
 {
-    if(!encoding.isEmpty())
-        self()->mChannelEncodingsMap[server][channel.lower()]=encoding;
-    else
-    {
-        self()->mChannelEncodingsMap[server].remove(channel.lower());
-        if(self()->mChannelEncodingsMap[server].count()==0)
-            self()->mChannelEncodingsMap.remove(server);
-    }
+    setChannelEncoding(serverGroupIdByName(server),channel,encoding);
 }
 
-const QStringList Preferences::channelEncodingsServerList()
+void Preferences::setChannelEncoding(int serverGroupId,const QString& channel,const QString& encoding)
+{
+    self()->mChannelEncodingsMap[serverGroupId][channel.lower()]=encoding;
+}
+
+const QValueList<int> Preferences::channelEncodingsServerGroupIdList()
 {
     return self()->mChannelEncodingsMap.keys();
 }
 
-const QStringList Preferences::channelEncodingsChannelList(const QString& server)
+const QStringList Preferences::channelEncodingsChannelList(int serverGroupId)
 {
-    return self()->mChannelEncodingsMap[server].keys();
+    return self()->mChannelEncodingsMap[serverGroupId].keys();
 }
 
 const QString Preferences::defaultNicknameSortingOrder()
