@@ -15,31 +15,39 @@
 #ifndef KONV_DCOP_H
 #define KONV_DCOP_H
 
+#include "konviface.h"
+#include "common.h"
+
 #include <qobject.h>
 #include <dcopobject.h>
-#include <qptrlist.h>
 
-#include "konviface.h"
 
 class KonvDCOP : public QObject, virtual public KonvIface
 {
     Q_OBJECT
 
-        public:
+    public:
         KonvDCOP();
 
         QString getNickname (const QString &server);
         QString getAnyNickname ();
         QString getChannelEncoding(const QString& server, const QString& channel);
 
-        signals:
+    signals:
         void dcopSay(const QString& server,const QString& target,const QString& command);
         void dcopInfo(const QString& string);
-        void dcopInsertRememberLine();
-        void dcopConnectToServer(const QString& url, int port, const QString& channel, const QString& password);
+        void dcopInsertMarkerLine();
         void dcopRaw(const QString& server, const QString& command);
         void dcopMultiServerRaw(const QString& command);
 
+        void connectTo(Konversation::ConnectionFlag flag,
+                       const QString& hostName,
+                       const QString& port = "",
+                       const QString& password = "",
+                       const QString& nick = "",
+                       const QString& channel = "",
+                       bool useSSL = false);
+
     public slots:
         void setAway(const QString &awaymessage);
         void setBack();
@@ -50,10 +58,13 @@ class KonvDCOP : public QObject, virtual public KonvIface
         void info(const QString& string);
         void debug(const QString& string);
         void error(const QString& string);
-        void insertRememberLine();
-        void connectToServer(const QString& url, int port, const QString& channel, const QString& password);
+        void insertMarkerLine();
+        void connectToServer(const QString& adress, int port, const QString& channel, const QString& password);
         QStringList listServers();
         QStringList listConnectedServers();
+
+        void setScreenSaverStarted();
+        void setScreenSaverStopped();
 };
 
 class KonvIdentDCOP : public QObject, virtual public KonvIdentityIface
@@ -79,6 +90,8 @@ class KonvIdentDCOP : public QObject, virtual public KonvIdentityIface
         void setNicknameList(const QString &identity, const QStringList& newList);
         QStringList getNicknameList(const QString &identity);
 
+        void setQuitReason(const QString &identity, const QString& reason);
+        QString getQuitReason(const QString &identity);
         void setPartReason(const QString &identity, const QString& reason);
         QString getPartReason(const QString &identity);
         void setKickReason(const QString &identity, const QString& reason);
