@@ -1,55 +1,22 @@
 /*
- *  This file is part of the KDE libraries
- *  Copyright (C) 2003 Benjamin C Meyer (ben+kdelibs at meyerhome dot net)
- *  Copyright (C) 2003 Waldo Bastian <bastian@kde.org>
- *  Copyright (C) 2004 Michael Brade <brade@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+*/
 
 /*
- *  KConfigDialog derivative allowing for a multi-level hierarchical TreeList.
- *  Differences from KConfigDialog:
- *  - Use QStringList instead of QString for the item name(s) in addPage and
- *    addPageInternal, thus calling the respective KDialogBase methods which
- *    allow specifying a path from which the TreeList hierarchy is constructed.
- *  - Use 16x16 icons in the TreeList.
- *  See the KConfigDialog reference for detailed documentation.
- *
- *  begin:     Nov 22 2005
- *  copyright: (C) 2005 by Eike Hein, KConfigDialog developers
- *  email:     sho@eikehein.com
- */
-
-#include <qsplitter.h>
+  Copyright (C) 2006 John Tapsell <johnflux@gmail.com>
+  Copyright (C) 2006 Eike Hein <hein@kde.org>
+*/
 
 #include "konvisettingsdialog.h"
 #include "konviconfigdialog.h"
 #include "config/preferences.h"
-
-#include <klocale.h>
-#include <kdebug.h>
-#include <kiconloader.h>
-#include <klistview.h>
-
 #include "chatwindowappearance_preferences.h"
 #include "connectionbehavior_preferences.h"
 #include "highlight_preferences.h"
 #include "warnings_preferences.h"
-#include "chatwindowappearance_preferences.h"
 #include "log_preferences.h"
 #include "quickbuttons_preferences.h"
 #include "autoreplace_preferences.h"
@@ -67,6 +34,15 @@
 #include "watchednicknames_preferences.h"
 #include "tabnotifications_preferences.h"
 
+#include <qsplitter.h>
+#include <qcombobox.h>
+
+#include <klocale.h>
+#include <kdebug.h>
+#include <kiconloader.h>
+#include <klistview.h>
+
+
 KonviSettingsDialog::KonviSettingsDialog( QWidget *parent) :
 	           KonviConfigDialog( parent, "settings", Preferences::self(), KDialogBase::TreeList)
 {
@@ -94,6 +70,9 @@ KonviSettingsDialog::KonviSettingsDialog( QWidget *parent) :
 
   //Interface/Chat Window
   m_confChatWindowAppearanceWdg = new ChatWindowAppearance_Config( 0, "ChatWindowAppearance" );
+  m_confChatWindowAppearanceWdg->kcfg_TimestampFormat->insertItem("hh:mm");
+  m_confChatWindowAppearanceWdg->kcfg_TimestampFormat->insertItem("hh:mm:ss");
+  m_confChatWindowAppearanceWdg->kcfg_TimestampFormat->insertItem("h:m ap");
   pagePath.clear();
   pagePath << i18n("Interface") << i18n("Chat Window");
   addPage ( m_confChatWindowAppearanceWdg, pagePath, "view_text", i18n("Chat Window") );
@@ -162,7 +141,7 @@ KonviSettingsDialog::KonviSettingsDialog( QWidget *parent) :
   m_confAliasWdg = new Alias_Config( this, "Alias" );
   pagePath.clear();
   pagePath << i18n("Behavior") << i18n("Command Aliases");
-  addPage ( m_confAliasWdg, pagePath, "editcopy", i18n(" Command Aliases") );
+  addPage ( m_confAliasWdg, pagePath, "editcopy", i18n("Command Aliases") );
   m_indexToPageMapping.insert(lastAddedIndex(), m_confAliasWdg);
   connect(m_confAliasWdg, SIGNAL(modified()), this, SLOT(modifiedSlot()));
 
