@@ -7,9 +7,21 @@
 
 /*
   Copyright (C) 2002 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2005 Eike Hein <sho@eikehein.com>
+  Copyright (C) 2005-2008 Eike Hein <hein@kde.org>
 */
 
+#include "query.h"
+#include "channel.h"
+#include "server.h"
+#include "konversationapplication.h"
+#include "konversationmainwindow.h"
+#include "viewcontainer.h"
+#include "ircinput.h"
+#include "ircview.h"
+#include "ircviewbox.h"
+#include "common.h"
+#include "topiclabel.h"
+
 #include <qhbox.h>
 #include <qcheckbox.h>
 #include <qlabel.h>
@@ -28,18 +40,10 @@
 #include <kstringhandler.h>
 #include <kpopupmenu.h>
 
-#include "channel.h"
-#include "query.h"
-#include "server.h"
-#include "konversationapplication.h"
-#include "ircinput.h"
-#include "ircview.h"
-#include "ircviewbox.h"
-#include "common.h"
-#include "topiclabel.h"
 
-Query::Query(QWidget* parent) : ChatWindow(parent)
+Query::Query(QWidget* parent, QString _name) : ChatWindow(parent)
 {
+    name=_name; // need the name a little bit earlier for setServer
     // don't setName here! It will break logfiles!
     //   setName("QueryWidget");
     setType(ChatWindow::Query);
@@ -74,6 +78,7 @@ Query::Query(QWidget* parent) : ChatWindow(parent)
 
     // link "Whois", "Ignore" ... menu items into ircview popup
     QPopupMenu* popup=textView->getPopup();
+    popup->insertSeparator();
     popup->insertItem(i18n("&Whois"),Konversation::Whois);
     popup->insertItem(i18n("&Version"),Konversation::Version);
     popup->insertItem(i18n("&Ping"),Konversation::Ping);
@@ -83,13 +88,9 @@ Query::Query(QWidget* parent) : ChatWindow(parent)
     popup->insertItem(i18n("Unignore"), Konversation::UnignoreNick);
     popup->setItemVisible(Konversation::IgnoreNick, false);
     popup->setItemVisible(Konversation::UnignoreNick, false);
-    popup->insertSeparator();
 
     if (kapp->authorize("allow_downloading"))
-    {
         popup->insertItem(SmallIcon("2rightarrow"),i18n("Send &File..."),Konversation::DccSend);
-        popup->insertSeparator();
-    }
 
     popup->insertItem(i18n("Add to Watched Nicks"), Konversation::AddNotify);
 
@@ -99,6 +100,9 @@ Query::Query(QWidget* parent) : ChatWindow(parent)
 
     awayLabel=new QLabel(i18n("(away)"),inputBox);
     awayLabel->hide();
+    blowfishLabel = new QLabel(inputBox);
+    blowfishLabel->hide();
+    blowfishLabel->setPixmap(KGlobal::iconLoader()->loadIcon("encrypted", KIcon::Toolbar));
     queryInput=new IRCInput(inputBox);
 
     getTextView()->installEventFilter(queryInput);
@@ -111,8 +115,6 @@ Query::Query(QWidget* parent) : ChatWindow(parent)
     connect(getTextView(), SIGNAL(textPasted(bool)), queryInput, SLOT(paste(bool)));
     connect(getTextView(),SIGNAL (gotFocus()),queryInput,SLOT (setFocus()) );
 
-    connect(textView, SIGNAL(updateTabNotification(Konversation::TabNotifyType)),
-        this, SLOT(activateTabNotification(Konversation::TabNotifyType)));
     connect(textView,SIGNAL (sendFile()),this,SLOT (sendFileMenu()) );
     connect(textView,SIGNAL (extendedPopup(int)),this,SLOT (popup(int)) );
     connect(textView,SIGNAL (autoText(const QString&)),this,SLOT (sendQueryText(const QString&)) );
@@ -126,9 +128,40 @@ Query::~Query()
 {
 }
 
+void Query::setServer(Server* newServer)
+{
+    if (m_server != newServer)
+        connect(newServer, SIGNAL(connectionStateChanged(Server*, Konversation::ConnectionState)),
+                SLOT(connectionStateChanged(Server*, Konversation::ConnectionState)));
+
+    ChatWindow::setServer(newServer);
+
+    if (newServer->getKeyForRecipient(getName()))
+        blowfishLabel->show();
+}
+
+void Query::connectionStateChanged(Server* server, Konversation::ConnectionState state)
+{
+    if (server == m_server)
+    {
+        if (state ==  Konversation::SSConnected)
+        {
+            //HACK the way the notification priorities work sucks, this forces the tab text color to ungray right now.
+            if (m_currentTabNotify == Konversation::tnfNone || !Preferences::tabNotificationsEvents())
+                KonversationApplication::instance()->getMainWindow()->getViewContainer()->unsetViewNotification(this);
+        }
+        else
+        {
+            //HACK the way the notification priorities work sucks, this forces the tab text color to gray right now.
+            if (m_currentTabNotify == Konversation::tnfNone || (!Preferences::tabNotificationsEvents() && m_currentTabNotify == Konversation::tnfControl))
+                KonversationApplication::instance()->getMainWindow()->getViewContainer()->unsetViewNotification(this);
+        }
+    }
+}
+
 void Query::setName(const QString& newName)
 {
-    if(ChatWindow::getName() == newName) return;  // no change, so return
+    //if(ChatWindow::getName() == newName) return;  // no change, so return
 
     ChatWindow::setName(newName);
 
@@ -148,10 +181,18 @@ void Query::setName(const QString& newName)
     }
 }
 
+void Query::setEncryptedOutput(bool e)
+{
+    if (e)
+        blowfishLabel->show();
+    else
+        blowfishLabel->hide();
+}
+
 void Query::queryTextEntered()
 {
     QString line=queryInput->text();
-    queryInput->clear();
+    queryInput->setText("");
     if(line.lower()==Preferences::commandChar()+"clear")
     {
         textView->clear();
@@ -171,7 +212,7 @@ void Query::queryPassthroughCommand()
     QString commandChar = Preferences::commandChar();
     QString line = queryInput->text();
 
-    queryInput->clear();
+    queryInput->setText("");
 
     if(!line.isEmpty())
     {
@@ -191,7 +232,7 @@ void Query::sendQueryText(const QString& sendLine)
     // replace aliases and wildcards
     if(m_server->getOutputFilter()->replaceAliases(outputAll))
     {
-        outputAll = m_server->parseWildcards(outputAll, m_server->getNickname(), getName(), QString::null, QString::null, QString::null);
+        outputAll = m_server->parseWildcards(outputAll, m_server->getNickname(), getName(), QString(), QString(), QString());
     }
 
     // Send all strings, one after another
@@ -220,11 +261,11 @@ void Query::sendQueryText(const QString& sendLine)
             }
         }
 
-        if (result.toServerList.count())
+        if (!result.toServerList.empty())
         {
             m_server->queueList(result.toServerList);
         }
-        else //per the original code, an empty string could be queued
+        else
         {
             m_server->queue(result.toServer);
         }
@@ -261,7 +302,7 @@ void Query::updateAppearance()
     else
     {
         getTextView()->setViewBackground(Preferences::color(Preferences::TextViewBackground),
-            QString::null);
+            QString());
     }
 
     if (Preferences::customTextFont())
@@ -332,27 +373,35 @@ void Query::showEvent(QShowEvent*)
 void Query::popup(int id)
 {
     // get the nickname to the context menu popup
-    QString name=textView->getContextNick();
+    QString name = textView->getContextNick();
     // if there was none (right click into the text view) assume query partner
-    if(name.isEmpty()) name=getName();
+    if (name.isEmpty()) name = getName();
 
-    switch(id)
+    switch (id)
     {
         case Konversation::Whois:
             sendQueryText(Preferences::commandChar()+"WHOIS "+name+' '+name);
             break;
 
         case Konversation::IgnoreNick:
-	    {
-              sendQueryText(Preferences::commandChar()+"IGNORE -ALL "+name+"!*");
-              int rc=KMessageBox::questionYesNo(this,
+        {
+            if (KMessageBox::warningContinueCancel(this, i18n("Do you want to ignore %1?").arg(name),
+                i18n("Ignore"), i18n("Ignore"), "IgnoreNick") == KMessageBox::Continue)
+            {
+                sendQueryText(Preferences::commandChar()+"IGNORE -ALL "+name);
+
+                int rc = KMessageBox::questionYesNo(this,
                 i18n("Do you want to close this query after ignoring this nickname?"),
                 i18n("Close This Query"),
                 i18n("Close"),
                 i18n("Keep Open"),
                 "CloseQueryAfterIgnore");
-              if(rc==KMessageBox::Yes) closeYourself();
-              break;
+
+                if (rc == KMessageBox::Yes && m_server)
+                    QTimer::singleShot(0, this, SLOT(closeWithoutAsking()));
+            }
+
+            break;
         }
         case Konversation::UnignoreNick:
         {
@@ -363,12 +412,18 @@ void Query::popup(int id)
             {
                 sendQueryText(Preferences::commandChar()+"UNIGNORE "+name);
             }
+
             break;
         }
         case Konversation::AddNotify:
-            if (!Preferences::isNotify(m_server->serverGroupSettings()->id(), name))
-                Preferences::addNotify(m_server->serverGroupSettings()->id(),name);
+        {
+            if (m_server->getServerGroup())
+            {
+                if (!Preferences::isNotify(m_server->getServerGroup()->id(), name))
+                    Preferences::addNotify(m_server->getServerGroup()->id(),name);
+            }
             break;
+        }
         case Konversation::DccSend:
             sendQueryText(Preferences::commandChar()+"DCC SEND "+name);
             break;
@@ -385,7 +440,7 @@ void Query::popup(int id)
             m_server->requestTopic(getTextView()->currentChannel());
             break;
         case Konversation::Names:
-            m_server->queue("NAMES " + getTextView()->currentChannel());
+            m_server->queue("NAMES " + getTextView()->currentChannel(), Server::LowPriority);
             break;
         case Konversation::Join:
             m_server->queue("JOIN " + getTextView()->currentChannel());
@@ -431,7 +486,7 @@ void Query::nickInfoChanged()
         if(!m_nickInfo->getHostmask().isEmpty() && !text.isEmpty())
             text += " - ";
         text += m_nickInfo->getHostmask();
-        if(m_nickInfo->isAway() )
+        if(m_nickInfo->isAway() && !m_nickInfo->getAwayMessage().isEmpty())
             text += " (" + KStringHandler::rsqueeze(m_nickInfo->getAwayMessage(),100) + ") ";
         queryHostmask->setText(Konversation::removeIrcMarkup(text));
 
@@ -507,20 +562,30 @@ QString Query::getTextInLine() { return queryInput->text(); }
 bool Query::canBeFrontView()        { return true; }
 bool Query::searchView()       { return true; }
 
-void Query::appendInputText(const QString& s)
+void Query::appendInputText(const QString& s, bool fromCursor)
 {
-    queryInput->setText(queryInput->text() + s);
+    if(!fromCursor)
+    {
+        queryInput->append(s);
+    }
+    else
+    {
+        int para = 0, index = 0;
+        queryInput->getCursorPosition(&para, &index);
+        queryInput->insertAt(s, para, index);
+        queryInput->setCursorPosition(para, index + s.length());
+    }
 }
 
                                                   // virtual
 void Query::setChannelEncoding(const QString& encoding)
 {
-    Preferences::setChannelEncoding(m_server->getServerGroup(), getName(), encoding);
+    Preferences::setChannelEncoding(m_server->getDisplayName(), getName(), encoding);
 }
 
 QString Query::getChannelEncoding()               // virtual
 {
-    return Preferences::channelEncoding(m_server->getServerGroup(), getName());
+    return Preferences::channelEncoding(m_server->getDisplayName(), getName());
 }
 
 QString Query::getChannelEncodingDefaultDesc()    // virtual
@@ -528,16 +593,13 @@ QString Query::getChannelEncodingDefaultDesc()    // virtual
     return i18n("Identity Default ( %1 )").arg(getServer()->getIdentity()->getCodecName());
 }
 
-bool Query::closeYourself()
+bool Query::closeYourself(bool confirm)
 {
-    int result=KMessageBox::warningContinueCancel(
-        this,
-        i18n("Do you want to close your query with %1?").arg(getName()),
-        i18n("Close Query"),
-        i18n("Close"),
-        "QuitQueryTab");
+    int result = KMessageBox::Continue;
+    if (confirm)
+        result=KMessageBox::warningContinueCancel(this, i18n("Do you want to close your query with %1?").arg(getName()), i18n("Close Query"), i18n("Close"), "QuitQueryTab");
 
-    if(result==KMessageBox::Continue)
+    if (result == KMessageBox::Continue)
     {
         m_server->removeQuery(this);
         return true;
@@ -546,6 +608,11 @@ bool Query::closeYourself()
     return false;
 }
 
+void Query::closeWithoutAsking()
+{
+    m_server->removeQuery(this);
+}
+
 void Query::filesDropped(const QStrList& files)
 {
     m_server->sendURIs(files,getName());
