@@ -8,24 +8,15 @@
 /*
   Copyright (C) 2002 Dario Abatianni <eisfuchs@tigress.com>
   Copyright (C) 2005 Ismail Donmez <ismail@kde.org>
-  Copyright (C) 2005 Peter Simonsson <psn@linux.se>
-  Copyright (C) 2005 Eike Hein <sho@eikehein.com>
+  Copyright (C) 2005-2006 Peter Simonsson <psn@linux.se>
+  Copyright (C) 2006-2008 Eli J. MacKenzie <argonel at gmail.com>
+  Copyright (C) 2005-2008 Eike Hein <hein@kde.org>
 */
 
 #ifndef SERVER_H
 #define SERVER_H
 
-#include <qtimer.h>
-#include <qdict.h>
-
-#include <qdeepcopy.h>
-
-#include <ksharedptr.h>
-#include <kprocess.h>
-#include <ksocketbase.h>
-#include <kbufferedsocket.h>
-#include <kstreamsocket.h>
-
+#include "common.h"
 #include "channelnick.h"
 #include "inputfilter.h"
 #include "outputfilter.h"
@@ -33,9 +24,22 @@
 #include "sslsocket.h"
 #include "serversettings.h"
 #include "servergroupsettings.h"
+#include "connectionsettings.h"
+
+#include <qtimer.h>
+#include <qvaluevector.h>
+#include <qguardedptr.h>
+
+#include <ksharedptr.h>
+#include <kprocess.h>
+#include <ksocketbase.h>
+#include <kbufferedsocket.h>
+#include <kstreamsocket.h>
+
 
 class Channel;
 class DccTransfer;
+class DccTransferPanelItem;
 class Query;
 class StatusPanel;
 class Identity;
@@ -49,64 +53,54 @@ class ViewContainer;
 
 using namespace KNetwork;
 
+class IRCQueue;
+
 class Server : public QObject
 {
     Q_OBJECT
-
+    friend class IRCQueue;
+    friend class QueueTuner;
+void resetNickSelection();
     public:
-        typedef enum
+        enum QueuePriority
         {
-            SSDisconnected,
-            SSConnecting,
-            SSConnected
-        } State;
-        /** Constructor used for connecting to a known server.
-         *  Read in the prefrences to get all the details about the server.
-         */
-        Server(ViewContainer* viewContainer, int serverGroupId, bool clearQuickServerList = true);
+            LowPriority,      ///<slow queue, for automatic info gathering
+            StandardPriority, ///<regular queue, for chat and user initiated commands
+            HighPriority,     ///<for pongs and quits
 
-        /** Constructor used for a 'fast connect' to a server.
-         *  The details are passed in.  Used for example when the user does "/server irc.somewhere.net"
-         */
-        Server(ViewContainer* viewContainer, const QString& hostName,const QString& port,
-            const QString& channel,const QString& nick, const QString& password, const bool& useSSL=false);
+            Howmanyqueuesdoweneedanywayquestionmark,
+
+            HiPriority=HighPriority,
+            LoPriority=LowPriority,
+            NormalPriorty=StandardPriority,
+            RegularPriority=StandardPriority
+        };
+
+        Server(QObject* parent, ConnectionSettings& settings);
         ~Server();
 
-        QString getServerName() const;
-        QString getServerGroup() const;
+        int connectionId() { return m_connectionId; }
 
-        void resetCurrentServerIndex() { m_currentServerIndex = 0; }
+        ConnectionSettings& getConnectionSettings() { return m_connectionSettings; }
+        void setConnectionSettings(ConnectionSettings& settings) { m_connectionSettings = settings; }
 
-        Konversation::ServerGroupSettingsPtr serverGroupSettings() const { return m_serverGroup; }
+        QString getDisplayName() { return m_connectionSettings.name(); }
+        QString getServerName() { return m_connectionSettings.server().host(); }
 
-        IdentityPtr getIdentity() const;
+        Konversation::ServerGroupSettingsPtr getServerGroup() { return m_connectionSettings.serverGroup(); }
+        IdentityPtr getIdentity() { return m_connectionSettings.identity(); }
+
+        Konversation::ConnectionState getConnectionState() { return m_connectionState; }
+
+        bool isConnected() { return (m_connectionState == Konversation::SSConnected); }
+        bool isConnecting() { return (m_connectionState == Konversation::SSConnecting); }
 
         bool getUseSSL() const;
         QString getSSLInfo() const;
-
-        int getPort() const;
+        int getPort();
         int getLag() const;
 
-        bool getAutoJoin() const;
-        void setAutoJoin(bool on);
-
-        /** This returns true when we have a socket connection.
-         *	Not necessarily 'online' and ready for commands.
-         *  @see connected()
-         */
-        bool isConnected() const;
-        bool isConnecting() const;
-
-        QString getAutoJoinChannel() const;
-        void setAutoJoinChannel(const QString &channel);
-
-        QString getAutoJoinChannelKey() const;
-        void setAutoJoinChannelKey(const QString &key);
-
-        QString getNextNickname();
-
-        void setIrcName(const QString &newIrcName);
-        QString getIrcName() const;
+        void updateAutoJoin(Konversation::ChannelSettings channel = Konversation::ChannelSettings());
 
         void resetNickList(const QString& channelName);
         void addPendingNickList(const QString& channelName,const QStringList& nickList);
@@ -131,13 +125,15 @@ class Server : public QObject
         QString getNickname() const;
         QString loweredNickname() const;
 
-        InputFilter* getInputFilter();
-        Konversation::OutputFilter* getOutputFilter();
+        QString getNextNickname();
+
+        InputFilter* getInputFilter() { return &m_inputFilter; }
+        Konversation::OutputFilter* getOutputFilter() { return m_outputFilter; };
 
         void joinChannel(const QString& name, const QString& hostmask);
         void removeChannel(Channel* channel);
         void appendServerMessageToChannel(const QString& channel, const QString& type, const QString& message);
-        void appendCommandMessageToChannel(const QString& channel, const QString& command, const QString& message);
+        void appendCommandMessageToChannel(const QString& channel, const QString& command, const QString& message, bool highlight = true);
         void appendStatusMessage(const QString& type,const QString& message);
         void appendMessageToFrontmost(const QString& type,const QString& message, bool parseURL = true);
 
@@ -159,8 +155,6 @@ class Server : public QObject
         QString parseWildcards(const QString& toParse, const QString& nickname, const QString& channelName, const QString &channelKey, const QStringList &nickList, const QString& parameter);
         QString parseWildcards(const QString& toParse, const QString& nickname, const QString& channelName, const QString &channelKey, const QString& nick, const QString& parameter);
 
-        QString getAutoJoinCommand() const;
-
         void autoCommandsAndChannels();
 
         void sendURIs(const QStrList& uris, const QString& nick);
@@ -168,13 +162,21 @@ class Server : public QObject
         void notifyAction(const QString& nick);
         ChannelListPanel* getChannelListPanel() const;
 
-        StatusPanel* getStatusView() const { return statusView; }
+        StatusPanel* getStatusView() const { return m_statusView; }
+        virtual bool closeYourself(bool askForConfirmation=true);
+
+        QString getOwnIpByNetworkInterface();
+        QString getOwnIpByServerMessage();
+
+        void requestAway(const QString& reason = "");
+        void requestUnaway();
+
+        bool isAway() { return m_away; }
+        void setAway(bool away);
+        QString awayTime() const;
+
+        void setAwayReason(const QString& reason) { m_awayReason = reason; }
 
-        /** This returns true when we are 'online' - ready to take commands, join channels and so on.
-         */
-        bool connected() const;
-        QString getIp(bool followDccSetting = false);
-        QString getNumericalIp(bool followDccSetting = false);
         /**
          * Returns true if the given nickname is known to be online.
          * @param nickname      The nickname.  Case insensitive.
@@ -284,17 +286,7 @@ class Server : public QObject
         /**
          * Returns a QPtrList of all channels
          */
-        QPtrList<Channel> getChannelList() const { return channelList; }
-
-        /** Returns the time we have been away for.
-         *  If we are not away, returns 00:00:00
-         */
-        QString awayTime() const;
-        /** Does the _server_ think we are away.  Note that if we went auto-away when not connected to the server, this may
-         *  return false.
-         */
-        bool isAway() const;
-        void setAwayReason(const QString& reason);
+        const QPtrList<Channel>& getChannelList() const { return m_channelList; }
 
         void emitChannelNickChanged(const ChannelNickPtr channelNick);
         void emitNickInfoChanged(const NickInfoPtr nickInfo);
@@ -341,34 +333,77 @@ class Server : public QObject
 
         ChannelListPanel* addChannelListPanel();
 
+        // invoked by DccTransferSend
+        void dccSendRequest(const QString& recipient,const QString& fileName,const QString& address,const QString& port,unsigned long size);
+        void dccPassiveSendRequest(const QString& recipient,const QString& fileName,const QString& address,unsigned long size,const QString& token);
+        // invoked by DccTransferRecv
+        void dccResumeGetRequest(const QString& sender,const QString& fileName,const QString& port,KIO::filesize_t startAt);
+        void dccReverseSendAck(const QString& partnerNick,const QString& fileName,const QString& ownAddress,const QString& ownPort,unsigned long size,const QString& reverseToken);
+
+    // IRCQueueManager
+        bool validQueue(QueuePriority priority); ///< is this queue index valid?
+        void resetQueues(); ///< Tell all of the queues to reset
+        static int _max_queue() { return Howmanyqueuesdoweneedanywayquestionmark-1; }
+
+        /** Forces the queued data to be sent in sequence of age, without pause.
+
+            This could flood you off but since you're quitting, we probably don't care. This is done
+            here instead of in the queues themselves so we can interleave the queues without having to
+            zip the queues together. If you want to quit the server normally without sending, reset the queues
+            first.
+         */
+        void flushQueues();
+
+        //These are really only here to limit where ircqueue.h is included
+        static void _fetchRates(); ///< on server construction
+        static void _stashRates(); ///< on application exit
+        static void _resetRates(); ///< when QueueTuner says to
+
+
     signals:
+        void destroyed(int connectionId);
         void nicknameChanged(const QString&);
         void serverLag(Server* server,int msec);  /// will be connected to KonversationMainWindow::updateLag()
         void tooLongLag(Server* server, int msec);/// will be connected to KonversationMainWindow::updateLag()
-        void resetLag();
-                                                  /// Will be emitted when new 303 came in
+        void resetLag(); ///< will be emitted when new 303 came in
         void nicksNowOnline(Server* server,const QStringList& list,bool changed);
-        void deleted(Server* myself);             /// will be connected to KonversationApplication::removeServer()
         void awayState(bool away);                /// will be connected to any user input panel;
         void multiServerCommand(const QString& command, const QString& parameter);
 
-        /// Emitted when the server gains/loses connection.
-        void serverOnline(bool state);            /// will be connected to all server dependant tabs
+        /**
+         * Emitted when the server gains/loses connection.
+         * Will be connected to all server dependant tabs.
+         */
+        void serverOnline(bool state);
 
-        /// Note that these signals haven't been implemented yet.
+        /**
+         * Emitted every time something gets sent.
+         *
+         *  @param  bytes           The count of bytes sent to the server, before re-encoding.
+         *  @param  encodedBytes    The count of bytes sent to the server after re-encoding.
+         */
+        void sentStat(int bytes, int encodedBytes, IRCQueue *whichQueue);
+        //FIXME can anyone who can connect to a Server signal not know about an IRCQueue?
+        void sentStat(int bytes, int encodedBytes);
+
+        //Note that these signals haven't been implemented yet.
         /// Fires when the information in a NickInfo object changes.
         void nickInfoChanged(Server* server, const NickInfoPtr nickInfo);
+
         /// Fires when the mode of a nick in a channel changes.
         void channelNickChanged(Server* server, const ChannelNickPtr channelNick);
+
         /// Fires when a nick leaves or joins a channel.  Based on joined flag, receiver could
         /// call getJoinedChannelMembers or getUnjoinedChannelMembers, or just
         /// getChannelMembers to get a list of all the nicks now in the channel.
         /// parted indicates whether the nick joined or left the channel.
         void channelMembersChanged(Server* server, const QString& channelName, bool joined, bool parted, const QString& nickname);
+
         /// Fires when a channel is moved to/from the Joinied/Unjoined lists.
         /// joined indicates which list it is now on.  Note that if joined is False, it is
         /// possible the channel does not exist in any list anymore.
         void channelJoinedOrUnjoined(Server* server, const QString& channelName, bool joined);
+
         /// Fires when a nick on the watch list goes online or offline.
         void watchedNickChanged(Server* server, const QString& nickname, bool online);
         ///Fires when the user switches his state to away and has enabled "Insert Remember Line on away" in his identity.
@@ -376,18 +411,20 @@ class Server : public QObject
         void sslInitFailure();
         void sslConnected(Server* server);
 
-        void connectionChangedState(Server* server, Server::State state);
+        void connectionStateChanged(Server* server, Konversation::ConnectionState state);
 
         void showView(ChatWindow* view);
         void addDccPanel();
-        void addDccChat(const QString& myNick,const QString& nick,const QString& numericalIp,const QStringList& arguments,bool listen);
+        void addDccChat(const QString& myNick,const QString& nick,const QStringList& arguments,bool listen);
 
     public slots:
-        void lookupFinished();
         void connectToIRCServer();
-        void queue(const QString &buffer);
-        void queueList(const QStringList &buffer);
-        void queueAt(uint pos,const QString& buffer);
+
+        /** Adds line to queue if non-empty. */
+        bool queue(const QString& line, QueuePriority priority=StandardPriority);
+        //TODO this should be an overload, not a separate name. ambiguous cases need QString() around the cstring
+        bool queueList(const QStringList& buffer, QueuePriority priority=StandardPriority);
+
         void setNickname(const QString &newNickname);
         /** This is called when we want to open a new query, or focus an existing one.
          *  @param nickInfo The nickinfo we want to open the query to.  Must exist.
@@ -398,14 +435,15 @@ class Server : public QObject
         void closeQuery(const QString &name);
         void closeChannel(const QString &name);
         void quitServer();
-        void requestDccChat(const QString& nickname);
+        void openDccChat(const QString& nickname);
+        void requestDccChat(const QString& partnerNick, const QString& numericalOwnIp, const QString& ownPort);
         void requestBan(const QStringList& users,const QString& channel,const QString& option);
         void requestUnban(const QString& mask,const QString& channel);
 
-        void addDccSend(const QString &recipient,KURL fileURL, const QString &altFileName = QString::null, uint fileSize = 0);
+        void addDccSend(const QString &recipient,KURL fileURL, const QString &altFileName = QString(), uint fileSize = 0);
         void removeQuery(Query *query);
         void startNotifyTimer(int msec=0);
-        void sendJoinCommand(const QString& channelName, const QString& password = QString::null);
+        void sendJoinCommand(const QString& channelName, const QString& password = QString());
         void requestChannelList();
         void requestWhois(const QString& nickname);
         void requestWho(const QString& channel);
@@ -420,9 +458,7 @@ class Server : public QObject
         void sendMultiServerCommand(const QString& command, const QString& parameter);
         void executeMultiServerCommand(const QString& command, const QString& parameter);
         void reconnect();
-        void disconnect();
-        void connectToServerGroup(const QString& serverGroup);
-        void connectToNewServer(const QString& server, const QString& port, const QString& password);
+        void disconnect(); //FIXME is this overriding a qobject method? do we care?
         void showSSLDialog();
         void sendToAllChannels(const QString& text);
         void notifyTimeout();
@@ -436,18 +472,15 @@ class Server : public QObject
         void pongReceived();
 
     protected slots:
-
+        void lookupFinished();
         void preShellCommandExited(KProcess*);
         void ircServerConnectionSuccess();
         void startAwayTimer();
-        void lockSending();
-        void unlockSending();
         void incoming();
         void processIncomingData();
-        void send();
-        /**
-         *Because KBufferedSocket has no closed(int) signal we use this slot to call broken(0)
-         */
+        /// Sends the QString to the socket. No longer has any internal concept of queueing
+        void toServer(QString&, IRCQueue *);
+        /// Because KBufferedSocket has no closed(int) signal we use this slot to call broken(0)
         void closed();
         void broken(int state);
         /** This is connected to the SSLSocket failed.
@@ -456,6 +489,8 @@ class Server : public QObject
         void sslError(const QString& reason);
         void connectionEstablished(const QString& ownHost);
         void notifyResponse(const QString& nicksOnline);
+        void slotNewDccTransferItemQueued(DccTransfer* transfer);
+        void startReverseDccSendTransfer(const QString& sourceNick,const QStringList& dccArguments);
         void addDccGet(const QString& sourceNick,const QStringList& dccArguments);
         void requestDccSend();                    // -> to outputFilter, dccPanel
                                                   // -> to outputFilter
@@ -464,17 +499,13 @@ class Server : public QObject
         void resumeDccGetTransfer(const QString& sourceNick,const QStringList& dccArguments);
                                                   // -> to inputFilter
         void resumeDccSendTransfer(const QString& sourceNick,const QStringList& dccArguments);
-        void dccSendRequest(const QString& recipient,const QString& fileName,const QString& address,const QString& port,unsigned long size);
-        void dccResumeGetRequest(const QString& sender,const QString& fileName,const QString& port,KIO::filesize_t startAt);
-        void dccGetDone(const DccTransfer* item);
-        void dccSendDone(const DccTransfer* item);
-        void dccStatusChanged(const DccTransfer* item, int newStatus, int oldStatus);
-        void away();
-        void unAway();
+        void dccGetDone(DccTransfer* item);
+        void dccSendDone(DccTransfer* item);
+        void dccStatusChanged(DccTransfer* item, int newStatus, int oldStatus);
         void scriptNotFound(const QString& name);
         void scriptExecutionError(const QString& name);
         void userhost(const QString& nick,const QString& hostmask,bool away,bool ircOp);
-        void setTopicAuthor(const QString& channel,const QString& author);
+        void setTopicAuthor(const QString& channel,const QString& author, QDateTime t);
         void endOfWho(const QString& target);
         void invitation(const QString& nick,const QString& channel);
         void sendToAllChannelsAndQueries(const QString& text);
@@ -486,23 +517,27 @@ class Server : public QObject
         /// Updates GUI when the lag gets high
         void updateLongPongLag();
 
+        /// Update the encoding shown in the mainwindow's actions
+        void updateEncoding();
+
+    private slots:
+        void collectStats(int bytes, int encodedBytes);
+
+        /** Called in the server constructor if the preferences are set to run a command on a new server instance.
+         *  This sets up the kprocess, runs it, and connects the signals to call preShellCommandExited when done. */
+        void doPreShellCommand();
+
     protected:
         // constants
         static const int BUFFER_LEN=513;
 
-        /// Initialize the class
-        void init(ViewContainer* viewContainer, const QString& nick, const QString& channel);
-
         /// Initialize the timers
         void initTimers();
 
         /// Connect to the signals used in this class.
         void connectSignals();
 
-        void setViewContainer(ViewContainer* newViewContainer);
-
-        void autoRejoinChannels();
-        void updateAutoJoin(const QString& channel=QString::null);
+        int _send_internal(QString outputline); ///< Guts of old send, isn't a slot.
 
         /** Adds a nickname to the unjoinedChannels list.
          *  Creates new NickInfo if necessary.
@@ -514,6 +549,7 @@ class Server : public QObject
          *  @return            The NickInfo for the nickname.
          */
         ChannelNickPtr addNickToUnjoinedChannelsList(const QString& channelName, const QString& nickname);
+
         /**
          * If not already online, changes a nick to the online state by creating
          * a NickInfo for it and emits various signals and messages for it.
@@ -522,6 +558,16 @@ class Server : public QObject
          * @return                   Pointer to NickInfo for nick.
          */
         NickInfoPtr setWatchedNickOnline(const QString& nickname);
+
+        /**
+        * Display offline notification for a certain nickname. The function doesn't change NickInfo objects.
+        * If NickInfoPtr is given, then also the integration with KAddressBook is engaged (i.e. the
+        * nick is marked as away)
+        * @param nickname           The nickname that is offline
+        * @param nickInfo           Pointer to NickInfo for nick
+        */
+        void setWatchedNickOffline(const QString& nickname, const NickInfoPtr nickInfo);
+
         /**
          * If nickname is no longer on any channel list, or the query list, delete it altogether.
          * Call this routine only if the nick is not on the notify list or is on the notify
@@ -529,7 +575,8 @@ class Server : public QObject
          * @param nickname           The nickname to be deleted.  Case insensitive.
          * @return                   True if the nickname is deleted.
          */
-        bool deleteNickIfUnlisted(QString &nickname);
+        bool deleteNickIfUnlisted(const QString &nickname);
+
         /**
          * If not already offline, changes a nick to the offline state.
          * Removes it from all channels on the joined and unjoined lists.
@@ -542,104 +589,88 @@ class Server : public QObject
          * @return             True if the nick was online.
          */
         bool setNickOffline(const QString& nickname);
+
         /** Remove nickname from a channel (on joined or unjoined lists).
          *  @param channelName The channel name.  Case insensitive.
          *  @param nickname    The nickname.  Case insensitive.
          */
         void removeChannelNick(const QString& channelName, const QString& nickname);
+
         /** Remove channel from the joined list.
          *  Nicknames in the channel are added to the unjoined list if they are in the watch list.
          *  @param channelName The channel name.  Case insensitive.
          */
         void removeJoinedChannel(const QString& channelName);
+
         /** Renames a nickname in all NickInfo lists.
          *  @param nickInfo    Pointer to existing NickInfo object.
          *  @param newname     New nickname for the nick.  Case sensitive.
          */
         void renameNickInfo(NickInfoPtr nickInfo, const QString& newname);
 
-        /** Called in the server constructor if the preferences are set to run a command on a new server instance.
-         *  This sets up the kprocess, runs it, and connects the signals to call preShellCommandExited when done. */
-        void doPreShellCommand();
+        bool getAutoJoin() const;
+        void setAutoJoin(bool on);
 
-        unsigned int completeQueryPosition;
-        unsigned int tryNickNumber;
-        unsigned int reconnectCounter;
+        QStringList getAutoJoinCommands() const { return m_autoJoinCommands; }
+        void setAutoJoinCommands(const QStringList& commands) { m_autoJoinCommands = commands; }
 
-        QString bot;
-        QString botPassword;
+        unsigned int m_completeQueryPosition;
+        QValueList<int> m_nickIndices;
+        QStringList m_referenceNicklist;
 
         // TODO roll these into a QMap.
-        QString serverNickPrefixes;               // Prefixes used by the server to indicate a mode
-        QString serverNickPrefixModes;            // if supplied: modes related to those prefixes
-        QString channelPrefixes;                  // prefixes that indicate channel names. defaults to RFC1459 "#&"
+        QString m_serverNickPrefixes;               // Prefixes used by the server to indicate a mode
+        QString m_serverNickPrefixModes;            // if supplied: modes related to those prefixes
+        QString m_channelPrefixes;                  // prefixes that indicate channel names. defaults to RFC1459 "#&"
 
-        bool autoJoin;
-        bool quickConnect;
-        bool deliberateQuit;
-        bool keepViewsOpenAfterQuit;
-        bool reconnectAfterQuit;
+        bool m_autoJoin;
 
-        QString autoJoinChannel;
-        QString autoJoinChannelKey;
-
-        ViewContainer* m_viewContainerPtr;
+        QStringList m_autoJoinCommands;
 
         KNetwork::KStreamSocket* m_socket;
-        bool         m_tryReconnect;
 
-        QTimer reconnectTimer;
-        QTimer incomingTimer;
-        QTimer outgoingTimer;
-        QTimer unlockTimer;                       // timeout waiting for server to send initial messages
+        QTimer m_reconnectTimer;
+        QTimer m_incomingTimer;
+        QTimer m_notifyTimer;
+        QStringList m_notifyCache;                  // List of users found with ISON
+        int m_checkTime;                            // Time elapsed while waiting for server 303 response
+        int m_currentLag;
 
-        int timerInterval;                        // flood protection
+        QCString m_inputBufferIncomplete;
+        QStringList m_inputBuffer;
 
-        QTimer notifyTimer;
-        QStringList notifyCache;                  // List of users found with ISON
-        int checkTime;                            // Time elapsed while waiting for server 303 response
-        int currentLag;
+        QValueVector<IRCQueue *> m_queues;
+        int m_bytesSent, m_encodedBytesSent, m_linesSent, m_bytesReceived;
 
-        QString ircName;
-        QCString inputBufferIncomplete;
-        QStringList inputBuffer;
-        QStringList outputBuffer;
-        QString nickname;
+        QString m_nickname;
         QString m_loweredNickname;
-        QString ownIpByUserhost;                  // RPL_USERHOST
-        QString ownIpByWelcome;                   // RPL_WELCOME
-        QString lastDccDir;
+        QString m_ownIpByUserhost;                  // RPL_USERHOST
+        QString m_ownIpByWelcome;                   // RPL_WELCOME
 
-        QPtrList<Channel> channelList;
-        QPtrList<Query> queryList;
+        QPtrList<Channel> m_channelList;
+        QPtrList<Query> m_queryList;
 
-        InputFilter inputFilter;
-        Konversation::OutputFilter* outputFilter;
+        InputFilter m_inputFilter;
+        Konversation::OutputFilter* m_outputFilter;
 
-        StatusPanel* statusView;
-        RawLog* rawLog;
-        ChannelListPanel* channelListPanel;
+        QGuardedPtr<StatusPanel> m_statusView;
+        QGuardedPtr<RawLog> m_rawLog;
+        QGuardedPtr<ChannelListPanel> m_channelListPanel;
 
-        bool m_isAway;
+        bool m_away;
         QString m_awayReason;
-
-        bool alreadyConnected;
-        bool rejoinChannels;
-        bool sendUnlocked;
-        bool connecting;
-
-        QString nonAwayNick;
-
+        QString m_nonAwayNick;
         int m_awayTime;
 
+        Konversation::ConnectionState m_connectionState;
+        void updateConnectionState(Konversation::ConnectionState state);
+        bool isSocketConnected() const;
+
         ScriptLauncher* m_scriptLauncher;
 
-        KProcess preShellCommand;
+        KProcess m_preShellCommand;
 
     private:
-        /// The server we're going to connect to initially.
-        Konversation::ServerSettings m_quickServer;
-
         /// Helper object to construct ISON (notify) list and map offline nicks to
         /// addressbook.
         ServerISON* m_serverISON;
@@ -658,15 +689,13 @@ class Server : public QObject
         /// List of nicks in Queries.
         NickInfoMap m_queryNicks;
 
-        Konversation::ServerGroupSettingsPtr m_serverGroup;
-        unsigned int m_currentServerIndex;
-
         QString m_allowedChannelModes;
 
         // Blowfish key map
-        QMap<QString,QCString> keyMap;
+        QMap<QString,QCString> m_keyMap;
 
         bool m_identifyMsg;
+        bool m_autoIdentifyLock;
 
         /// Used to lock incomingTimer while processing message.
         bool m_processingIncoming;
@@ -676,6 +705,13 @@ class Server : public QObject
         /// Updates the gui when the lag gets too high
         QTimer m_pingResponseTimer;
 
-        bool m_autoIdentifyLock;
+        /// Previous ISON reply of the server, needed for comparison with the next reply
+        QStringList m_prevISONList;
+
+        ConnectionSettings m_connectionSettings;
+
+        static int m_availableConnectionId;
+        int m_connectionId;
 };
+
 #endif
